@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Emitter;
 
-our $VERSION = '0.003_001'; # TRIAL VERSION
+our $VERSION = '0.003_002'; # TRIAL VERSION
 
 use constant DEBUG => $ENV{YAML_PP_EMIT_DEBUG};
 
@@ -397,7 +397,12 @@ sub scalar_event {
         if ($props and length $value) {
             $props .= ' ';
         }
-        $$yaml .= "- $props$value";
+        if ($props or length $value) {
+            $$yaml .= "- $props$value";
+        }
+        else {
+            $$yaml .= "-";
+        }
         if ($style ne '|' and $style ne '>') {
             $$yaml .= "\n";
         }
@@ -432,7 +437,7 @@ sub alias_event {
     my $alias = '*' . $info->{content};
 
     if ($stack->[-1] eq 'MAP') {
-        $$yaml .= "$indent$alias:";
+        $$yaml .= "$indent$alias :";
         $stack->[-1] = 'MAPVALUE';
     }
     elsif ($stack->[-1] eq 'MAPVALUE') {
@@ -452,12 +457,12 @@ sub document_start_event {
     DEBUG and warn __PACKAGE__.':'.__LINE__.": +++ document_start_event\n";
     my ($self, $info) = @_;
     my $yaml = $self->yaml;
-    if ($info->{content}) {
-        $$yaml .= "---";
-        $self->set_first(1);
+    if ($info->{implicit}) {
+        $self->set_first(0);
     }
     else {
-        $self->set_first(0);
+        $$yaml .= "---";
+        $self->set_first(1);
     }
 }
 
@@ -465,7 +470,7 @@ sub document_end_event {
     DEBUG and warn __PACKAGE__.':'.__LINE__.": +++ document_end_event\n";
     my ($self, $info) = @_;
     my $yaml = $self->yaml;
-    if ($info->{content}) {
+    unless ($info->{implicit}) {
         $$yaml .= "...\n";
     }
 }
@@ -491,7 +496,7 @@ sub emit_tag {
         $tag = "$1";
     }
     else {
-        warn __PACKAGE__.':'.__LINE__.$".Data::Dumper->Dump([\$tag], ['tag']);
+#        warn __PACKAGE__.':'.__LINE__.$".Data::Dumper->Dump([\$tag], ['tag']);
         $tag = "!$tag";
     }
     return $tag;
